@@ -2,11 +2,13 @@
 
 from pfmsoft.aiohttp_queue.aiohttp import (
     ActionCallbacks,
+    ActionObserver,
+    ActionState,
     AiohttpAction,
     AiohttpActionCallback,
-    AiohttpQueueWorkerFactory,
+    AiohttpQueueWorker,
 )
 
 __author__ = """Chad Lowe"""
 __email__ = "pfmsoft@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.1.8"
